@@ -8,9 +8,9 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Backend::Xorg ;
-$Config::Model::Backend::Xorg::VERSION = '1.111';
+$Config::Model::Backend::Xorg::VERSION = '1.112';
 
-use Any::Moose ;
+use Mouse ;
 use Carp ;
 use Log::Log4perl qw(get_logger :levels);
 
@@ -84,8 +84,6 @@ sub write {
     return 1;
 }
 
-no Any::Moose ;
-__PACKAGE__->meta->make_immutable ;
 
 1;
 
@@ -97,7 +95,7 @@ Config::Model::Backend::Xorg - Read and write config from xorg.conf file
 
 =head1 VERSION
 
-version 1.111
+version 1.112
 
 =head1 SYNOPSIS
 
